summaryrefslogtreecommitdiffstats
path: root/src/sys/prof/idletask.C
diff options
context:
space:
mode:
Diffstat (limited to 'src/sys/prof/idletask.C')
-rw-r--r--src/sys/prof/idletask.C10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/sys/prof/idletask.C b/src/sys/prof/idletask.C
index da568f955..1c38835ce 100644
--- a/src/sys/prof/idletask.C
+++ b/src/sys/prof/idletask.C
@@ -42,11 +42,11 @@ void TaskManager::idleTaskLoop(void* unused)
// Lower priority (and yield simics thread).
setThreadPriorityLow();
- // Request privilege escalation for doze.
- register uint64_t syscall = MISC_CPUDOZE;
- asm volatile("or 3, %0, %0; sc" :: "r" (syscall) : "r3");
+ // Request privilege escalation for nap.
+ register uint64_t syscall = MISC_CPUNAP;
+ asm volatile("or 3, %0, %0; sc" :: "r" (syscall) : "r3", "cc");
- // Execute doze.
- doze();
+ // Execute nap.
+ nap();
}
}
OpenPOWER on IntegriCloud